@@ -98,11 +98,10 @@ struct _CcInfoPanelPrivate
   char          *gnome_date;
   UpdatesState   updates_state;
 
-  GCancellable  *cancellable;
-
   /* Free space */
   GList         *primary_mounts;
   guint64        total_bytes;
+  GCancellable  *cancellable;
 
   /* Media */
   GSettings     *media_settings;
@@ -312,7 +311,6 @@ get_graphics_data_glx_renderer ()
     None
   };
   int nconfigs;
-  int major, minor;
   Window window;
   GLXFBConfig *config;
   GLXWindow glxwin;
@@ -325,7 +323,6 @@ get_graphics_data_glx_renderer ()
 
   display = GDK_DISPLAY_XDISPLAY (gdk_display_get_default ());
 
-  glXQueryVersion (display, &major, &minor);
   config = glXChooseFBConfig (display, DefaultScreen (display),
                               attributes, &nconfigs);
   if (config == NULL) {
@@ -475,11 +472,7 @@ cc_info_panel_finalize (GObject *object)
 {
   CcInfoPanelPrivate *priv = CC_INFO_PANEL (object)->priv;
 
-  if (priv->cancellable)
-    {
-      g_cancellable_cancel (priv->cancellable);
-      g_clear_object (&priv->cancellable);
-    }
+  g_clear_pointer (&priv->cancellable, g_cancellable_cancel);
   g_free (priv->gnome_version);
   g_free (priv->gnome_date);
   g_free (priv->gnome_distributor);
@@ -825,7 +818,7 @@ set_virtualization_label (CcInfoPanel  *self,
   display_name = NULL;
   for (i = 0; i < G_N_ELEMENTS (virt_tech); i++)
     {
-      if (g_str_equal (virt_tech[i].id, virt))
+      if (g_str_equal (virt_tech[i].id, virt) == 0)
         {
           display_name = _(virt_tech[i].display);
           break;
@@ -1378,7 +1371,6 @@ info_panel_setup_media (CcInfoPanel *self)
     { "x-content/video-svcd", N_("Super Video CD") },
     { "x-content/video-vcd", N_("Video CD") },
     { "x-content/win32-software", N_("Windows software") },
-    { "x-content/software", N_("Software") }
   };
 
   for (n = 0; n < G_N_ELEMENTS (defs); n++) {
@@ -1794,24 +1786,18 @@ got_pk_proxy_cb (GObject *source_object,
 {
   GError *error = NULL;
   guint32 major, minor, micro;
-  GDBusProxy *proxy;
 
-  proxy = g_dbus_proxy_new_for_bus_finish (res, &error);
+  self->priv->pk_proxy = g_dbus_proxy_new_for_bus_finish (res, &error);
 
-  if (proxy == NULL)
+  if (self->priv->pk_proxy == NULL)
     {
-      if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-        {
-          g_warning ("Unable to get PackageKit proxy object: %s", error->message);
-          self->priv->updates_state = PK_NOT_AVAILABLE;
-          refresh_update_button (self);
-        }
+      g_warning ("Unable to get PackageKit proxy object: %s", error->message);
       g_error_free (error);
+      self->priv->updates_state = PK_NOT_AVAILABLE;
+      refresh_update_button (self);
       return;
     }
 
-  self->priv->pk_proxy = proxy;
-
   if (!get_pk_version_property(self->priv->pk_proxy, "VersionMajor", &major) ||
       !get_pk_version_property(self->priv->pk_proxy, "VersionMinor", &minor) ||
       !get_pk_version_property(self->priv->pk_proxy, "VersionMicro", &micro))
@@ -1840,25 +1826,9 @@ got_pk_proxy_cb (GObject *source_object,
     }
 }
 
-static gboolean
-does_prepared_update_exist (void)
-{
-  return g_file_test ("/var/lib/PackageKit/prepared-update", G_FILE_TEST_EXISTS);
-}
-
 static void
 info_panel_setup_updates (CcInfoPanel *self)
 {
-  if (does_gnome_software_exist ())
-    {
-      if (does_prepared_update_exist ())
-        self->priv->updates_state = UPDATES_AVAILABLE;
-      else
-        self->priv->updates_state = UPDATES_NOT_AVAILABLE;
-      refresh_update_button (self);
-      return;
-    }
-
   self->priv->updates_state = CHECKING_UPDATES;
   refresh_update_button (self);
 
@@ -1868,7 +1838,7 @@ info_panel_setup_updates (CcInfoPanel *self)
                             "org.freedesktop.PackageKit",
                             "/org/freedesktop/PackageKit",
                             "org.freedesktop.PackageKit",
-                            self->priv->cancellable,
+                            NULL,
                             (GAsyncReadyCallback) got_pk_proxy_cb,
                             self);
 }
