@@ -203,16 +203,12 @@ button_changed_cb (GtkComboBox *combo, gpointer user_data)
 			    BUTTONNUMBER_COLUMN, &mapping_b2,
 			    -1);
 
-	if (gsd_wacom_stylus_get_num_buttons (priv->stylus) > 1) {
-		if (!gtk_combo_box_get_active_iter (GTK_COMBO_BOX (WID ("combo-topbutton")), &iter))
-			return;
+	if (!gtk_combo_box_get_active_iter (GTK_COMBO_BOX (WID ("combo-topbutton")), &iter))
+		return;
 
-		gtk_tree_model_get (GTK_TREE_MODEL (liststore), &iter,
-				    BUTTONNUMBER_COLUMN, &mapping_b3,
-				    -1);
-	} else {
-		mapping_b3 = 0;
-	}
+	gtk_tree_model_get (GTK_TREE_MODEL (liststore), &iter,
+			    BUTTONNUMBER_COLUMN, &mapping_b3,
+			    -1);
 
 	map_button (priv->stylus_settings, mapping_b2, mapping_b3);
 }
@@ -333,7 +329,7 @@ cc_wacom_stylus_page_init (CcWacomStylusPage *self)
 
 	priv->nav = cc_wacom_nav_button_new ();
         gtk_widget_set_halign (priv->nav, GTK_ALIGN_END);
-        gtk_widget_set_margin_left (priv->nav, 10);
+        gtk_widget_set_margin_start (priv->nav, 10);
 	gtk_grid_attach (GTK_GRID (box), priv->nav, 1, 0, 1, 1);
 }
 
